Learn R Programming

OPSR (version 1.0.1)

OPSR-package: OPSR: Ordered Probit Switching Regression

Description

Estimates ordered probit switching regression models - a Heckman type selection model with an ordinal selection and continuous outcomes. Different model specifications are allowed for each treatment/regime. For more details on the method, see Wang & Mokhtarian (2024) tools:::Rd_expr_doi("10.1016/j.tra.2024.104072") or Chiburis & Lokshin (2007) tools:::Rd_expr_doi("10.1177/1536867X0700700202").

Arguments

Author

Maintainer: Daniel Heimgartner d.heimgartners@gmail.com (ORCID) [copyright holder]

Authors:

See Also